@@ -76,6 +76,7 @@
 
 #include "ext2_fs.h"
 #include "ext2fs.h"
+#include "ext2fsP.h"
 
 /*
  * For checking structure magic numbers...
@@ -185,6 +186,7 @@ static errcode_t raw_read_blk(io_channel channel,
 		actual = pread64(data->dev, buf, size, location);
 		if (actual == size)
 			return 0;
+		actual = 0;
 	}
 #elif HAVE_PREAD
 	/* Try an aligned pread */
@@ -195,6 +197,7 @@ static errcode_t raw_read_blk(io_channel channel,
 		actual = pread(data->dev, buf, size, location);
 		if (actual == size)
 			return 0;
+		actual = 0;
 	}
 #endif /* HAVE_PREAD */
 
@@ -247,7 +250,8 @@ bounce_read:
 	return 0;
 
 error_out:
-	memset((char *) buf+actual, 0, size-actual);
+	if (actual >= 0 && actual < size)
+		memset((char *) buf+actual, 0, size-actual);
 	if (channel->read_error)
 		retval = (channel->read_error)(channel, block, count, buf,
 					       size, actual, retval);
@@ -608,7 +612,7 @@ static errcode_t unix_open_channel(const char *name, int fd,
 	 * zero.
 	 */
 	if (ext2fs_fstat(data->dev, &st) == 0) {
-		if (S_ISBLK(st.st_mode))
+		if (ext2fsP_is_disk_device(st.st_mode))
 			io->flags |= CHANNEL_FLAGS_BLOCK_DEVICE;
 		else
 			io->flags |= CHANNEL_FLAGS_DISCARD_ZEROES;
@@ -679,7 +683,7 @@ static errcode_t unix_open_channel(const char *name, int fd,
 	     (ut.release[4] == '1') && (ut.release[5] >= '0') &&
 	     (ut.release[5] < '8')) &&
 	    (ext2fs_fstat(data->dev, &st) == 0) &&
-	    (S_ISBLK(st.st_mode))) {
+	    (ext2fsP_is_disk_device(st.st_mode))) {
 		struct rlimit	rlim;
 
 		rlim.rlim_cur = rlim.rlim_max = (unsigned long) RLIM_INFINITY;
